var contentTable;
    contentOptions = null;

async function initContentTable() {
    contentOptions = await getTrackedContentOptions();
    await initTable("#contentTabPane", "contentTable", loadContent, null, deleteSelectedContent, contentOptions);

    contentTable = $("#contentTable").DataTable({
        info: false,
        paging: false,
        ordering: false,
        searching: false,
        autoWidth: false,
        order: [],
        select: {
            style: "multi+shift",
            selector: 'th:first-child input[type="checkbox"]'
        },
        columnDefs: [
            { orderable: false, targets: "no-sort" },
            {
                targets: 0,
                checkboxes: { selectRow: true }
            }
        ],
        columns: [
            {
                // Select row checkbox column
                title: '<input type="checkbox" class="form-check-input table-select-all" />',
                data: null,
                orderable: false,
                className: "text-center col-switch-width",
                render: function() {
                    return '<input type="checkbox" class="form-check-input table-select-row" />'
                }
            },
            { data: "id", visible: false },
            {
                title: "GUID",
                data: "guid",
                className: "text-truncate mw-10rem",
            },
            {
                title: "Name",
                data: "title",
                className: "text-truncate",
                render: function(data, type, row) {
                    return `<a href="${row.url}" class="text-decoration-none" target="_blank">${data}</a>`
                }
            },
            {
                title: "Subscription",
                data: "subscription.name",
                className: "text-nowrap",
                render: function(data, type, row) {
                    return `<a href="#" onclick="goToSubscription(${row.subscription.id})" class="text-decoration-none">${data}</a>`
                }
            },
            {
                title: "Blocked",
                data: "blocked",
                className: "text-center col-1",
                render: function(data) {
                    return data ? `<i class="bi bi-check-lg text-success"></i>` : ""
                }
            },
            {
                title: "Channel",
                data: "channel_id",
                className: "text-start content-channel-id",
                render: function(data) {
                    return $("<span>").text(data)[0];
                }
            },
            {
                title: "Created",
                data: "creation_datetime",
                className: "text-nowrap",
                render: function(data, type) {
                    // return new Date(data).toISOString().split("T")[0];
                    let dateTime = new Date(data);
                    let dateTimeString = formatDate(dateTime);
                    return $(`
                    <span data-bs-trigger="hover focus"
                    data-bs-html="true"
                    data-bs-custom-class="text-center"
                    data-bs-toggle="popover"
                    data-bs-content="${dateTimeString}">
                    ${dateTime.toISOString().split("T")[0]}
                    </span>
                    `).popover()[0];
                }
            },
            {
                orderable: false,
                className: "p-0",
                render: function(data, type, row) {
                    return `<div class="h-100" style="background-color: #${row.subscription.embed_colour}; width: .25rem;">&nbsp;</div>`
                }
            }
        ]
    });

    bindTableCheckboxes("#contentTable", contentTable, "#contentTabPane .table-del-btn");
}

function handleDiscordChannelNames() {
    let interval = setInterval(function() {

        if (!discordChannels.length)
            return;

        $("#contentTable tr td.content-channel-id").each(function() {
            let tracked = contentTable.row($(this).closest("tr")).data();
                channel = discordChannels.find(item => item.value === tracked.channel_id);

            if (!channel)
                return;

            $(this).text("").append(
                $("<a>")
                .attr("href", `https://discord.com/channels/${getCurrentlyActiveServer().guild_id}/${channel.value}/${tracked.message_id}`)
                .attr("target", "_blank")
                .addClass("text-decoration-none")
                .text(channel.text)
            );
        });

        // $(".replace-discord-channel-id-with-name").each(function() {
        //     let displayChannel = discordChannels.find(channel => channel.value == $(this).text());
        //     if (displayChannel) {
        //         $(this).text("").append(
        //             $("<a>")
        //             .attr("href", `https://discord.com/channels/${getCurrentlyActiveServer().guild_id}/${displayChannel.value}`)
        //             .attr("target", "_blank")
        //             .addClass("text-decoration-none")
        //             .text(displayChannel.text)
        //         );
        //     }
        // });


    }, 600);
}

async function goToSubscription(subId) {
    $("#subscriptionsTab").click();
    await showEditSubModal(subId);
}

async function deleteSelectedContent() {

    var rows = contentTable.rows(".selected").data();
    $.each(rows, async function() {
        await deleteTrackedContent(this.id);
        showToast(
            "success",
            "Deletion Successful",
            `This content may appear again under the <b>${this.subscription.name}</b> Subscription:<br><br>${this.guid}`,
            10000
        );
    });

    setTimeout(async () => {
        await loadContent(getCurrentlyActiveServer().guild_id);
    }, 600)
}

function clearExistingContentRows() {
    $("#contentTable thead .table-select-all").prop("checked", false).prop("indeterminate", false);
    contentTable.clear().draw(false);
}

$("#contentTabPane").on("click", ".table-refresh-btn", async function() {
    loadContent(getCurrentlyActiveServer().guild_id);
});

async function loadContent(guildId) {

    if (!guildId)
        return;

    setTableFilter("contentTable", "subscription__guild_id", guildId);
    ensureTablePagination("contentTable");

    $("#contentTabPane .table-del-btn").prop("disabled", true);
    clearExistingContentRows();

    try {
        var content = await getTrackedContent(tableFilters["contentTable"], tableSorts["contentTable"]);
        contentTable.rows.add(content.results).draw(false);
    }
    catch (err) {
        console.error(err);
        showToast("danger", `Error loading Tracked Content: HTTP ${err.status}`, err, 15000);
        return;
    }

    updateTableContainer(
        "contentTabPane",
        tableFilters["contentTable"]["page"],
        tableFilters["contentTable"]["page_size"],
        content.results.length,
        content.count,
        content.next,
        content.previous
    );

    $("#contentTable thead .table-select-all").prop("disabled", content.results.length === 0);
    console.debug(`loaded filters, ${content.results.length} found`)
}

$(document).on("selectedServerChange", async function() {
    const activeServer = getCurrentlyActiveServer();
    await loadContent(activeServer.guild_id);
});
